AudioMetadata

data.datamodel.AudioMetadata()

Data model for the metadata of an audio file.

Attributes

Name Type Description
audio_path str Path to audio file.
sample_rate int Sample rate.
duration float Duration in seconds.
speeches list of SpeechSegment, optional List of speech segments in the audio.
metadata (dict, optional) Optional extra metadata.